# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKConnectedComponentsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkScalarConnectedComponentImageFilterPython
else:
    import _itkScalarConnectedComponentImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkConnectedComponentImageFilterPython
import itk.itkImageToImageFilterBPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython
import itk.itkScanlineFilterCommonPython

def itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_New():
    return itkScalarConnectedComponentImageFilterISS2ISS2_Superclass.New()

class itkScalarConnectedComponentImageFilterISS2ISS2_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterISS2ISS2):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< short > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS2ISS2_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS2ISS2_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Superclass_swigregister(itkScalarConnectedComponentImageFilterISS2ISS2_Superclass)

def itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_New():
    return itkScalarConnectedComponentImageFilterISS2IUL2_Superclass.New()

class itkScalarConnectedComponentImageFilterISS2IUL2_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterISS2IUL2):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS2IUL2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< short > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS2IUL2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS2IUL2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS2IUL2_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterISS2IUL2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS2IUL2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS2IUL2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS2IUL2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS2IUL2_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Superclass_swigregister(itkScalarConnectedComponentImageFilterISS2IUL2_Superclass)

def itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_New():
    return itkScalarConnectedComponentImageFilterISS3ISS3_Superclass.New()

class itkScalarConnectedComponentImageFilterISS3ISS3_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterISS3ISS3):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< short > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS3ISS3_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS3ISS3_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Superclass_swigregister(itkScalarConnectedComponentImageFilterISS3ISS3_Superclass)

def itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_New():
    return itkScalarConnectedComponentImageFilterISS3IUL3_Superclass.New()

class itkScalarConnectedComponentImageFilterISS3IUL3_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterISS3IUL3):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS3IUL3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< short > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< short > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS3IUL3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS3IUL3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS3IUL3_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterISS3IUL3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS3IUL3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS3IUL3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS3IUL3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS3IUL3_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Superclass_swigregister(itkScalarConnectedComponentImageFilterISS3IUL3_Superclass)

def itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_New():
    return itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass.New()

class itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterIUC2ISS2):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< unsigned char > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass_swigregister(itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass)

def itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_New():
    return itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass.New()

class itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterIUC2IUL2):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< unsigned char > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass_swigregister(itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass)

def itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_New():
    return itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass.New()

class itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterIUC3ISS3):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< unsigned char > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass_swigregister(itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass)

def itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_New():
    return itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass.New()

class itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass(itk.itkConnectedComponentImageFilterPython.itkConnectedComponentImageFilterIUC3IUL3):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char >
        GetFunctor(self) -> itk::Functor::SimilarPixelsFunctor< unsigned char > const &
        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::SimilarPixelsFunctor< unsigned char > const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_SetFunctor(self, functor)
    SameDimensionCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_SameDimensionCheck
    
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_OutputEqualityComparableCheck
    
    OutputConvertibleToUnsignedIntCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_OutputConvertibleToUnsignedIntCheck
    
    OutputConvertibleToUnsignedLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_OutputConvertibleToUnsignedLongCheck
    
    OutputConvertibleToLongCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_OutputConvertibleToLongCheck
    
    UnsignedLongConvertibleToOutputCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_UnsignedLongConvertibleToOutputCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass_swigregister(itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass)

def itkScalarConnectedComponentImageFilterISS2ISS2_New():
    return itkScalarConnectedComponentImageFilterISS2ISS2.New()

class itkScalarConnectedComponentImageFilterISS2ISS2(itkScalarConnectedComponentImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS2ISS2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS2ISS2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: short const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> short"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS2ISS2

        Create a new object of the class itkScalarConnectedComponentImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS2ISS2 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2ISS2_swigregister(itkScalarConnectedComponentImageFilterISS2ISS2)

def itkScalarConnectedComponentImageFilterISS2IUL2_New():
    return itkScalarConnectedComponentImageFilterISS2IUL2.New()

class itkScalarConnectedComponentImageFilterISS2IUL2(itkScalarConnectedComponentImageFilterISS2IUL2_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS2IUL2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS2IUL2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS2IUL2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: short const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> short"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS2IUL2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS2IUL2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS2IUL2

        Create a new object of the class itkScalarConnectedComponentImageFilterISS2IUL2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS2IUL2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS2IUL2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS2IUL2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS2IUL2 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS2IUL2_swigregister(itkScalarConnectedComponentImageFilterISS2IUL2)

def itkScalarConnectedComponentImageFilterISS3ISS3_New():
    return itkScalarConnectedComponentImageFilterISS3ISS3.New()

class itkScalarConnectedComponentImageFilterISS3ISS3(itkScalarConnectedComponentImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS3ISS3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS3ISS3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: short const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> short"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS3ISS3

        Create a new object of the class itkScalarConnectedComponentImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS3ISS3 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3ISS3_swigregister(itkScalarConnectedComponentImageFilterISS3ISS3)

def itkScalarConnectedComponentImageFilterISS3IUL3_New():
    return itkScalarConnectedComponentImageFilterISS3IUL3.New()

class itkScalarConnectedComponentImageFilterISS3IUL3(itkScalarConnectedComponentImageFilterISS3IUL3_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterISS3IUL3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterISS3IUL3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterISS3IUL3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: short const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> short"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterISS3IUL3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterISS3IUL3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterISS3IUL3

        Create a new object of the class itkScalarConnectedComponentImageFilterISS3IUL3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterISS3IUL3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterISS3IUL3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterISS3IUL3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterISS3IUL3 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterISS3IUL3_swigregister(itkScalarConnectedComponentImageFilterISS3IUL3)

def itkScalarConnectedComponentImageFilterIUC2ISS2_New():
    return itkScalarConnectedComponentImageFilterIUC2ISS2.New()

class itkScalarConnectedComponentImageFilterIUC2ISS2(itkScalarConnectedComponentImageFilterIUC2ISS2_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC2ISS2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC2ISS2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: unsigned char const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> unsigned char"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC2ISS2

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC2ISS2 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2ISS2_swigregister(itkScalarConnectedComponentImageFilterIUC2ISS2)

def itkScalarConnectedComponentImageFilterIUC2IUL2_New():
    return itkScalarConnectedComponentImageFilterIUC2IUL2.New()

class itkScalarConnectedComponentImageFilterIUC2IUL2(itkScalarConnectedComponentImageFilterIUC2IUL2_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC2IUL2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC2IUL2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC2IUL2_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: unsigned char const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> unsigned char"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC2IUL2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC2IUL2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC2IUL2

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC2IUL2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC2IUL2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC2IUL2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC2IUL2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC2IUL2 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC2IUL2_swigregister(itkScalarConnectedComponentImageFilterIUC2IUL2)

def itkScalarConnectedComponentImageFilterIUC3ISS3_New():
    return itkScalarConnectedComponentImageFilterIUC3ISS3.New()

class itkScalarConnectedComponentImageFilterIUC3ISS3(itkScalarConnectedComponentImageFilterIUC3ISS3_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC3ISS3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC3ISS3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: unsigned char const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> unsigned char"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC3ISS3

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC3ISS3 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3ISS3_swigregister(itkScalarConnectedComponentImageFilterIUC3ISS3)

def itkScalarConnectedComponentImageFilterIUC3IUL3_New():
    return itkScalarConnectedComponentImageFilterIUC3IUL3.New()

class itkScalarConnectedComponentImageFilterIUC3IUL3(itkScalarConnectedComponentImageFilterIUC3IUL3_Superclass):
    r"""Proxy of C++ itkScalarConnectedComponentImageFilterIUC3IUL3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarConnectedComponentImageFilterIUC3IUL3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarConnectedComponentImageFilterIUC3IUL3_Pointer"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_Clone(self)

    def SetDistanceThreshold(self, thresh):
        r"""
        SetDistanceThreshold(self, thresh)

        Parameters
        ----------
        thresh: unsigned char const &

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_SetDistanceThreshold(self, thresh)

    def GetDistanceThreshold(self):
        r"""GetDistanceThreshold(self) -> unsigned char"""
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_GetDistanceThreshold(self)
    InputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_OutputEqualityComparableCheck
    
    MaskEqualityComparableCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_MaskEqualityComparableCheck
    
    OutputIncrementDecrementOperatorsCheck = _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_OutputIncrementDecrementOperatorsCheck
    
    __swig_destroy__ = _itkScalarConnectedComponentImageFilterPython.delete_itkScalarConnectedComponentImageFilterIUC3IUL3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarConnectedComponentImageFilterIUC3IUL3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarConnectedComponentImageFilterIUC3IUL3

        Create a new object of the class itkScalarConnectedComponentImageFilterIUC3IUL3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarConnectedComponentImageFilterIUC3IUL3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarConnectedComponentImageFilterIUC3IUL3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarConnectedComponentImageFilterIUC3IUL3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarConnectedComponentImageFilterIUC3IUL3 in _itkScalarConnectedComponentImageFilterPython:
_itkScalarConnectedComponentImageFilterPython.itkScalarConnectedComponentImageFilterIUC3IUL3_swigregister(itkScalarConnectedComponentImageFilterIUC3IUL3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def connected_component_functor_image_filter(*args: itkt.ImageLike,  functor=..., fully_connected: bool=..., mask_image: itkt.Image=..., background_value: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ConnectedComponentFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor,'fully_connected':fully_connected,'mask_image':mask_image,'background_value':background_value }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ConnectedComponentFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def connected_component_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKConnectedComponents.ConnectedComponentFunctorImageFilter
    connected_component_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    connected_component_functor_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def scalar_connected_component_image_filter(*args: itkt.ImageLike,  distance_threshold: int=..., functor=..., fully_connected: bool=..., mask_image: itkt.Image=..., background_value: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ScalarConnectedComponentImageFilter"""
    import itk

    kwarg_typehints = { 'distance_threshold':distance_threshold,'functor':functor,'fully_connected':fully_connected,'mask_image':mask_image,'background_value':background_value }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ScalarConnectedComponentImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def scalar_connected_component_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKConnectedComponents.ScalarConnectedComponentImageFilter
    scalar_connected_component_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    scalar_connected_component_image_filter.__doc__ = filter_object.__doc__



